summaryrefslogtreecommitdiffstats
path: root/ash/screenshot_delegate.h
diff options
context:
space:
mode:
authormukai@chromium.org <mukai@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2012-02-03 23:09:54 +0000
committermukai@chromium.org <mukai@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2012-02-03 23:09:54 +0000
commit2e81938acb4b5f01738caa35b4bdf5758450b186 (patch)
tree82de49e72337c7f3398a50bd861ec0d63f118acb /ash/screenshot_delegate.h
parent7b2089cc5d47f0d3917979071be6eff716fe7b78 (diff)
downloadchromium_src-2e81938acb4b5f01738caa35b4bdf5758450b186.zip
chromium_src-2e81938acb4b5f01738caa35b4bdf5758450b186.tar.gz
chromium_src-2e81938acb4b5f01738caa35b4bdf5758450b186.tar.bz2
Push out RootWindow::GetInstance() from ScreenshotTaker.
Now it is called in ash and passed as an argument. BUG= TEST=manually verified && test passed locally Review URL: http://codereview.chromium.org/9325035 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@120427 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'ash/screenshot_delegate.h')
-rw-r--r--ash/screenshot_delegate.h13
1 files changed, 9 insertions, 4 deletions
diff --git a/ash/screenshot_delegate.h b/ash/screenshot_delegate.h
index b698a36..62ead29 100644
--- a/ash/screenshot_delegate.h
+++ b/ash/screenshot_delegate.h
@@ -1,4 +1,4 @@
-// Copyright (c) 2011 The Chromium Authors. All rights reserved.
+// Copyright (c) 2012 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
@@ -6,6 +6,10 @@
#define ASH_SCREENSHOT_DELEGATE_H_
#pragma once
+namespace aura {
+class Window;
+} // namespace aura
+
namespace ash {
// Delegate for taking screenshots.
@@ -13,9 +17,10 @@ class ScreenshotDelegate {
public:
virtual ~ScreenshotDelegate() {}
- // The actual task of taking a screenshot. This method is called
- // when the user wants to take a screenshot manually.
- virtual void HandleTakeScreenshot() = 0;
+ // The actual task of taking a screenshot for the given window.
+ // This method is called when the user wants to take a screenshot
+ // manually.
+ virtual void HandleTakeScreenshot(aura::Window* window) = 0;
};
} // namespace ash